==> attal_0.8.orig.tar.gz: attal-0.8/i18n/fr/scenario_editor_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Race :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Nombre :</translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Choisissez un sol</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Propriété de la base</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Possesseur :</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Bâtiments</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OkOk</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Nombre de créatures :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Comportement des créatures :</translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Ne fuit jamais :</translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation>Tournée vers la droite:</translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Propriété du seigneur</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Unités</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefacts</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Machines de guerre</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Techniques</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Erreur dans les propriétés du seigneur</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Un seigneur doit posséder au moins une unité</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Liste des artefacts disponibles</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Liste des artefacts du seigneur</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Choisir un joueur :</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Liste des techniques disponibles</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Liste des techniques du seigneur</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Liste des machines disponibles</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Liste des machines du seigneur</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Transition</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Décoration</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Bâtiment</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Seigneur</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefact</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Créature</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation>Bonus</translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation>Informatios générales du scénario</translation>
    </message>
    <message>
        <source>General Information</source>
        <translation>Informations générales</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation>Thème :</translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation>Nombre de joueurs :</translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation>Hauteur carte :</translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation>Largeur carte :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Map </source>
        <translation>Carte</translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation>Carte pour Attal</translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Sauvegarder</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Sauvegarder sous</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>&amp;Sauvegarder sous</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Informations sur le scenario</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Information sur le scénario</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Propriétés des joueurs</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Propriétés des joueurs</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Effacer la carte</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>Effacer la &amp;carte</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Remplir la carte</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Remplir la carte</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation>&amp;Scenario</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/fr/scenario_editor_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AskLordCharac</name>
    <message>
        <source>Charac</source>
        <translation>Caractéristique</translation>
    </message>
</context>
<context>
    <name>DisplayQuests</name>
    <message>
        <source>Main quest: </source>
        <translation>Quête principale :</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <source>Other quests:</source>
        <translation>Autres quêtes :</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Race :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Nombre :</translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Choisissez un sol</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (pondération=%d)</translation>
    </message>
</context>
<context>
    <name>NewQuestConditionDialog</name>
    <message>
        <source>AND</source>
        <translation>ET</translation>
    </message>
    <message>
        <source>OR</source>
        <translation>OU</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Seigneur</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Joueur</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Propriété de la base</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Possesseur :</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Bâtiments</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OkOk</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>PropertiesBonus</name>
    <message>
        <source>Resource: </source>
        <translation>Ressource :</translation>
    </message>
    <message>
        <source>Fixed value: </source>
        <translation>Valeur :</translation>
    </message>
    <message>
        <source>Primary skill: </source>
        <translation>Compétence primaire :</translation>
    </message>
    <message>
        <source>Attack</source>
        <translation>Attaque</translation>
    </message>
    <message>
        <source>Defense</source>
        <translation>Défense</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Puissance</translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation>Savoir</translation>
    </message>
    <message>
        <source>Morale</source>
        <translation>Moral</translation>
    </message>
    <message>
        <source>Luck</source>
        <translation>Chance</translation>
    </message>
    <message>
        <source>Add value: </source>
        <translation>Ajouter une valeur :</translation>
    </message>
    <message>
        <source>Bonus for secondary skills are not yet implemented</source>
        <translation>Les bonus pour les compétences secondaires ne sont pas encore implémentés</translation>
    </message>
    <message>
        <source>Bonus for spells are not yet implemented</source>
        <translation>Les bonus pour les sorts ne sont pas encore implémentés</translation>
    </message>
</context>
<context>
    <name>PropertiesBuilding</name>
    <message>
        <source>building properties</source>
        <translation>Propriété du bâtiment</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Possesseur :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Nombre de créatures :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Comportement des créatures :</translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Ne fuit jamais :</translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation>Tournée vers la droite:</translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation>Nombre de créatures dans l&apos;unité %d:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PropertiesEvent</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Propriété du seigneur</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Unités</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefacts</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Machines de guerre</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Techniques</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Erreur dans les propriétés du seigneur</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Un seigneur doit posséder au moins une unité</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Liste des artefacts disponibles</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Liste des artefacts du seigneur</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Choisir un joueur :</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Liste des techniques disponibles</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Liste des techniques du seigneur</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Liste des machines disponibles</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Liste des machines du seigneur</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Transition</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Décoration</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Bâtiment</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Seigneur</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefact</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Créature</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation>Bonus</translation>
    </message>
</context>
<context>
    <name>QuestConditionDateProperties</name>
    <message>
        <source>Before date: </source>
        <translation>Avant :</translation>
    </message>
    <message>
        <source>Day</source>
        <translation>Jour</translation>
    </message>
    <message>
        <source>Week</source>
        <translation>Semaine</translation>
    </message>
    <message>
        <source>Month</source>
        <translation>Mois</translation>
    </message>
    <message>
        <source>Before </source>
        <translation>Avant</translation>
    </message>
    <message>
        <source>day(s)</source>
        <translation>jour(s)</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QuestConditionDialog</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation>&amp;Propriétés</translation>
    </message>
    <message>
        <source>&amp;Add condition</source>
        <translation>&amp;Ajouter une condition</translation>
    </message>
    <message>
        <source>&amp;Delete condition</source>
        <translation>&amp;Supprimer</translation>
    </message>
</context>
<context>
    <name>QuestConditionEditor</name>
    <message>
        <source>Condition: </source>
        <translation>Condition :</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
</context>
<context>
    <name>QuestConditionLordProperties</name>
    <message>
        <source>Primary skill</source>
        <translation>Compétence primaire</translation>
    </message>
    <message>
        <source>value: </source>
        <translation>valeur :</translation>
    </message>
    <message>
        <source>Secondary skill</source>
        <translation>Compétence secondaire</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefact</translation>
    </message>
    <message>
        <source>Spell</source>
        <translation>Sort</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QuestEditor</name>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description :</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Ask player confirmation of quest</source>
        <translation>Demander confirmation de la quête</translation>
    </message>
    <message>
        <source>Confirmation question: </source>
        <translation>Question de confirmation :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Start condition: </source>
        <translation>Condition de démarrage :</translation>
    </message>
    <message>
        <source>Fail condition: </source>
        <translation>Condition d&apos;échec :</translation>
    </message>
    <message>
        <source>Success condition: </source>
        <translation>Condition de succès :</translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation>Informatios générales du scénario</translation>
    </message>
    <message>
        <source>General Information</source>
        <translation>Informations générales</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation>Thème :</translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation>Nombre de joueurs :</translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation>Hauteur carte :</translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation>Largeur carte :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description :</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Map </source>
        <translation>Carte</translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation>Carte pour Attal</translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Sauvegarder</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Sauvegarder sous</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>&amp;Sauvegarder sous</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Informations sur le scenario</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Information sur le scénario</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Propriétés des joueurs</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Propriétés des joueurs</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Effacer la carte</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>Effacer la &amp;carte</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Remplir la carte</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Remplir la carte</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation>&amp;Scenario</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Impossible de charger le thème</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Thème</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>n&apos;a pas été chargé correctement</translation>
    </message>
    <message>
        <source>Quests management</source>
        <translation>Gestion des quêtes</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Mini carte</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Mini carte</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
</context>
<context>
    <name>Screen</name>
    <message>
        <source>(Cell %dx%d)</source>
        <translation>(Case %dx%d)</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (pondération=%d)</translation>
    </message>
</context>
</TS>
